@@ -47,6 +47,8 @@ OC.L10N.register(
     "Previews" : "Vista previa",
     "In order to display real screenshots of your bookmarked websites, Bookmarks can use a third-party service to generate those." : "Con el fin de mostrar capturas de pantalla reales de sus sitios web marcados, la app Marcadores puede usar un servicio de terceros para generarlos.",
     "You can either sign up for free at <a href=\"http://screeenly.com\">screeenly.com</a> or <a href=\"https://github.com/stefanzweifel/screeenly\">setup your own server</a>." : "Puede registrarse gratis en <a href=\"http://screeenly.com\">screeenly.com</a> o <a href=\"https://github.com/stefanzweifel/screeenly\">configurar tu propio servidor</a>.",
+    "Screeenly API URL" : "URL de la API de Screeenly",
+    "Screeenly API key" : "Clave de la API de Screeenly",
     "Bookmarks feed" : "Fuente de marcadores"
 },
 "nplurals=2; plural=(n != 1);");
