@@ -2,9 +2,6 @@ OC.L10N.register(
     "bookmarks",
     {
     "Bookmarks" : "Favoris",
-    "Failed to import one bookmark, because: " : "Échec lors de l\\'importation d'un favori. Raison: ",
-    "No file provided for import" : "Aucun fichier à importer.",
-    "Unsupported file type for import" : "Type de fichier non pris en charge",
     "Add a Bookmark" : "Ajouter un favori",
     "Add folder" : "Ajouter un dossier",
     "Select" : "Sélectionner",
@@ -36,6 +33,9 @@ OC.L10N.register(
     "Import completed successfully." : "Importation terminée avec succès.",
     "Do you really want to delete all your bookmarks?" : "Voulez-vous réellement supprimer tous vos favoris ?",
     "Set tags" : "Choisir des étiquettes",
+    "Failed to import one bookmark, because: " : "Échec lors de l\\'importation d'un favori. Raison: ",
+    "No file provided for import" : "Aucun fichier à importer.",
+    "Unsupported file type for import" : "Type de fichier non pris en charge",
     "A Bookmark manager for Nextcloud" : "Un gestionnaire de favoris pour Nextcloud",
     "This app allows you to store and organize your favorite places on the web in one spot, while allowing you to sync them with your various devices and browsers.\nCheck out the third-party clients listed here: https://github.com/nextcloud/bookmarks#third-party-clients" : "Cette application vous permet d'enregistrer et d'organiser vos sites favoris du web en un seul lieu, et vous permettre de les synchroniser avec vos différents appareils et navigateurs.\nConsultez la liste des clients tiers ici : https://github.com/nextcloud/bookmarks#third-party-clients",
     "Add a bookmark" : "Ajouter un favori",
@@ -47,8 +47,8 @@ OC.L10N.register(
     "Previews" : "Prévisualisations",
     "In order to display real screenshots of your bookmarked websites, Bookmarks can use a third-party service to generate those." : "Pour afficher de vrais captures d'écran de vos sites internet mis en favoris, Favoris peux utiliser un service tiers pour les générer.",
     "You can either sign up for free at <a href=\"http://screeenly.com\">screeenly.com</a> or <a href=\"https://github.com/stefanzweifel/screeenly\">setup your own server</a>." : "Vous pouvez soit vous inscrire gratuitement sur <a href=\"http://screeenly.com\">screenly.com</a> ou <a href=\"https://github.com/stefanzweifel/screeenly\">configurer votre propre serveur</a>.",
-    "Screenly API URL" : "URL API Screenly",
-    "Screenly API key" : "Clé API Screenly",
+    "Screeenly API URL" : "URL API Screenly",
+    "Screeenly API key" : "Clé API Screenly",
     "Bookmarks feed" : "Flux de suivi"
 },
 "nplurals=2; plural=(n > 1);");
