@@ -9,14 +9,12 @@ use OC\BackgroundJob\TimedJob;
 use OCP\AppFramework\Utility\ITimeFactory;
 use OCP\IConfig;
 use OCP\IUserManager;
-use OCP\IUserSession;
 
 class PreviewsJob extends TimedJob {
 	public function __construct(
 		ITimeFactory $time,
 		IConfig $settings,
 		IUserManager $userManager,
-		IUserSession $userSession,
 		Bookmarks $libBookmarks,
 		DefaultPreviewService $defaultPreviews,
 		FaviconPreviewService $faviconPreviews,
@@ -24,7 +22,6 @@ class PreviewsJob extends TimedJob {
 	) {
 		$this->settings = $settings;
 		$this->userManager = $userManager;
-		$this->userSession = $userSession;
 		$this->libBookmarks = $libBookmarks;
 		$this->defaultPreviews = $defaultPreviews;
 		$this->faviconPreviews = $faviconPreviews;
@@ -42,12 +39,10 @@ class PreviewsJob extends TimedJob {
 		}
 		$allBookmarks = $this->libBookmarks->findBookmarks(-1, 0, 'lastmodified', [], true, -1);
 		foreach ($allBookmarks as $bookmark) {
-			$this->userSession->setUser($this->userManager->get($bookmark['user_id']));
 			if (null === $this->defaultPreviews->getImage($bookmark)) {
 				$this->screenlyPreviews->getImage($bookmark);
 			}
 			$this->faviconPreviews->getImage($bookmark);
 		}
-		$this->userSession->logout();
 	}
 }
