@@ -14,11 +14,14 @@ use OCP\IDBConnection;
 use OCP\IL10N;
 use OCP\ILogger;
 use \OCP\IRequest;
+use \OCP\IURLGenerator;
 use \OCP\AppFramework\ApiController;
 use \OCP\AppFramework\Http\JSONResponse;
 use \OCP\AppFramework\Http\DataResponse;
 use \OCP\AppFramework\Http\TemplateResponse;
 use \OCP\AppFramework\Http\DataDisplayResponse;
+use \OCP\AppFramework\Http\RedirectResponse;
+use \OCP\AppFramework\Http\NotFoundResponse;
 use \OCP\AppFramework\Http;
 use \OC\User\Manager;
 use \OCP\IUserSession;
@@ -56,7 +59,8 @@ class BookmarkController extends ApiController {
 		IPreviewService $screenshotService,
 		ITimeFactory $timeFactory,
 		ILogger $logger,
-		IUserSession $userSession
+		IUserSession $userSession,
+		IURLGenerator $url
 	) {
 		parent::__construct($appName, $request);
 		$this->userId = $userId;
@@ -71,6 +75,7 @@ class BookmarkController extends ApiController {
 		$this->timeFactory = $timeFactory;
 		$this->logger = $logger;
 		$this->userSession = $userSession;
+		$this->url = $url;
 	}
 
 	/**
@@ -148,7 +153,8 @@ class BookmarkController extends ApiController {
 		$search = [],
 		$limit = 10,
 		$untagged = false,
-		$folder = null
+		$folder = null,
+		$url = null
 	) {
 		$this->registerResponder('rss', function ($res) {
 			if ($res->getData()['status'] === 'success') {
@@ -216,6 +222,19 @@ class BookmarkController extends ApiController {
 
 		// type == bookmark
 
+		if ($url !== null) {
+			$id = $this->bookmarks->bookmarkExists($url, $user);
+			if ($id === false) {
+				return new DataResponse(['data' => [], 'status' => 'success']);
+			}
+			$bookmark = $this->bookmarks->findUniqueBookmark($id, $user);
+			if ($publicOnly && $bookmark['public'] != true) {
+				return new DataResponse(['data' => [], 'status' => 'success']);
+			}
+			$bookmarks = [$this->bookmarks->findUniqueBookmark($id, $user)];
+			return new DataResponse(['data' => $bookmarks, 'status' => 'success']);
+		}
+
 		if ($tag !== '') {
 			$filterTag = $this->bookmarks->analyzeTagRequest($tag);
 		} elseif (is_array($tags)) {
